@@ -1,10 +1,14 @@
+from __future__ import print_function
+from __future__ import absolute_import
 
 import datetime
-import io, csv, json
+import io
+import csv
+import json
 from sqlalchemy import Column, Integer, String, DateTime, Float, Text
 
-from db import Base
-from psiturk_config import PsiturkConfig
+from .db import Base
+from .psiturk_config import PsiturkConfig
 
 config = PsiturkConfig()
 config.load_config()
@@ -12,14 +16,16 @@ config.load_config()
 TABLENAME = config.get('Database Parameters', 'table_name')
 CODE_VERSION = config.get('Task Parameters', 'experiment_code_version')
 
+import six
+
 class Participant(Base):
     """
     Object representation of a participant in the database.
     """
     __tablename__ = TABLENAME
 
-    uniqueid =Column(String(128), primary_key=True)
-    assignmentid =Column(String(128), nullable=False)
+    uniqueid = Column(String(128), primary_key=True)
+    assignmentid = Column(String(128), nullable=False)
     workerid = Column(String(128), nullable=False)
     hitid = Column(String(128), nullable=False)
     ipaddress = Column(String(128))
@@ -32,8 +38,9 @@ class Participant(Base):
     beginhit = Column(DateTime)
     beginexp = Column(DateTime)
     endhit = Column(DateTime)
-    bonus = Column(Float, default = 0)
-    status = Column(Integer, default = 1)
+    bonus = Column(Float, default=0)
+    status = Column(Integer, default=1)
+    mode = Column(String(128))
     if 'postgres://' in config.get('Database Parameters', 'database_url').lower():
         datastring = Column(Text)
     else:
@@ -41,14 +48,14 @@ class Participant(Base):
 
     def __init__(self, **kwargs):
         self.uniqueid = "{workerid}:{assignmentid}".format(**kwargs)
-        for key in kwargs:
-            setattr(self, key, kwargs[key])
         self.status = 1
         self.codeversion = CODE_VERSION
         self.beginhit = datetime.datetime.now()
+        for key in kwargs:
+            setattr(self, key, kwargs[key])
 
     def __repr__(self):
-        return "Subject(%s, %s, %s, %s)" % (
+        return "Subject(uniqueid|%s, condition|%s, status|%s, codeversion|%s)" % (
             self.uniqueid,
             self.cond,
             self.status,
@@ -59,12 +66,16 @@ class Participant(Base):
             trialdata = json.loads(self.datastring)["data"]
         except (TypeError, ValueError):
             # There was no data to return.
-            print("No trial data found in record:", self)
+            print(("No trial data found in record:", self))
             return("")
+        
+        my_io = io.StringIO
+        if six.PY2:
+            my_io = io.BytesIO
 
         try:
             ret = []
-            with io.BytesIO() as outstring:
+            with my_io() as outstring:
                 csvwriter = csv.writer(outstring)
                 for trial in trialdata:
                     csvwriter.writerow((
@@ -75,7 +86,7 @@ class Participant(Base):
                 ret = outstring.getvalue()
             return ret
         except:
-            print("Error reading record:", self)
+            print(("Error reading record:", self))
             return("")
 
     def get_event_data(self):
@@ -83,19 +94,24 @@ class Participant(Base):
             eventdata = json.loads(self.datastring)["eventdata"]
         except (ValueError, TypeError):
             # There was no data to return.
-            print("No event data found in record:", self)
+            print(("No event data found in record:", self))
             return("")
 
+        my_io = io.StringIO
+        if six.PY2:
+            my_io = io.BytesIO
+
         try:
             ret = []
-            with io.BytesIO() as outstring:
+            with my_io() as outstring:
                 csvwriter = csv.writer(outstring)
                 for event in eventdata:
-                    csvwriter.writerow((self.uniqueid, event["eventtype"], event["interval"], event["value"], event["timestamp"]))
+                    csvwriter.writerow(
+                        (self.uniqueid, event["eventtype"], event["interval"], event["value"], event["timestamp"]))
                 ret = outstring.getvalue()
             return ret
         except:
-            print("Error reading record:", self)
+            print(("Error reading record:", self))
             return("")
 
     def get_question_data(self):
@@ -103,18 +119,29 @@ class Participant(Base):
             questiondata = json.loads(self.datastring)["questiondata"]
         except (TypeError, ValueError):
             # There was no data to return.
-            print("No question data found in record:", self)
+            print(("No question data found in record:", self))
             return("")
 
+        my_io = io.StringIO
+        if six.PY2:
+            my_io = io.BytesIO
+
         try:
             ret = []
-            with io.BytesIO() as outstring:
+            with my_io() as outstring:
                 csvwriter = csv.writer(outstring)
                 for question in questiondata:
-                    csvwriter.writerow((self.uniqueid, question, questiondata[question]))
+                    csvwriter.writerow(
+                        (self.uniqueid, question, questiondata[question]))
                 ret = outstring.getvalue()
             return ret
         except:
-            print("Error reading record:", self)
+            print(("Error reading record:", self))
             return("")
 
+
+class Hit(Base):
+    '''
+    '''
+    __tablename__ = 'amt_hit'
+    hitid = Column(String(128), primary_key=True)
